Enum SecondsFormat

enum SecondsFormat

Specific formatting options for seconds. This may be extended in the future, so exhaustive matching in external code is not recommended.

See the TimeZone::to_rfc3339_opts function for usage.

Variants

Secs

Format whole seconds only, with no decimal point nor subseconds.

Millis

Use fixed 3 subsecond digits. This corresponds to [Fixed::Nanosecond3].

Micros

Use fixed 6 subsecond digits. This corresponds to [Fixed::Nanosecond6].

Nanos

Use fixed 9 subsecond digits. This corresponds to [Fixed::Nanosecond9].

AutoSi

Automatically select one of Secs, Millis, Micros, or Nanos to display all available non-zero sub-second digits. This corresponds to [Fixed::Nanosecond].

Implementations

impl Clone for SecondsFormat

fn clone(self: &Self) -> SecondsFormat

impl Copy for SecondsFormat

impl Debug for SecondsFormat

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for SecondsFormat

impl Freeze for SecondsFormat

impl Hash for SecondsFormat

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for SecondsFormat

fn eq(self: &Self, other: &SecondsFormat) -> bool

impl RefUnwindSafe for SecondsFormat

impl Send for SecondsFormat

impl StructuralPartialEq for SecondsFormat

impl Sync for SecondsFormat

impl Unpin for SecondsFormat

impl UnsafeUnpin for SecondsFormat

impl UnwindSafe for SecondsFormat

impl<T> Any for SecondsFormat

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SecondsFormat

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SecondsFormat

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for SecondsFormat

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for SecondsFormat

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for SecondsFormat

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for SecondsFormat

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SecondsFormat

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SecondsFormat

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>