Function parse_and_remainder

fn parse_and_remainder<'a, 'b, I, B>(parsed: &mut Parsed, s: &'b str, items: I) -> ParseResult<&'b str>
where
    I: Iterator<Item = B>,
    B: Borrow<Item<'a>>

Tries to parse given string into parsed with given formatting items. Returns Ok with a slice of the unparsed remainder.

This particular date and time parser is: