Trait Timelike
trait Timelike: Sized
The common set of methods for time component.
Required Methods
fn hour(self: &Self) -> u32Returns the hour number from 0 to 23.
fn minute(self: &Self) -> u32Returns the minute number from 0 to 59.
fn second(self: &Self) -> u32Returns the second number from 0 to 59.
fn nanosecond(self: &Self) -> u32Returns the number of nanoseconds since the whole non-leap second. The range from 1,000,000,000 to 1,999,999,999 represents the leap second.
fn with_hour(self: &Self, hour: u32) -> Option<Self>Makes a new value with the hour number changed.
Returns
Nonewhen the resulting value would be invalid.fn with_minute(self: &Self, min: u32) -> Option<Self>Makes a new value with the minute number changed.
Returns
Nonewhen the resulting value would be invalid.fn with_second(self: &Self, sec: u32) -> Option<Self>Makes a new value with the second number changed.
Returns
Nonewhen the resulting value would be invalid. As with thesecondmethod, the input range is restricted to 0 through 59.fn with_nanosecond(self: &Self, nano: u32) -> Option<Self>Makes a new value with nanoseconds since the whole non-leap second changed.
Returns
Nonewhen the resulting value would be invalid. As with thenanosecondmethod, the input range can exceed 1,000,000,000 for leap seconds.
Provided Methods
fn hour12(self: &Self) -> (bool, u32)Returns the hour number from 1 to 12 with a boolean flag, which is false for AM and true for PM.
fn num_seconds_from_midnight(self: &Self) -> u32Returns the number of non-leap seconds past the last midnight.
Every value in 00:00:00-23:59:59 maps to an integer in 0-86399.
This method is not intended to provide the real number of seconds since midnight on a given day. It does not take things like DST transitions into account.
Implementors
impl Timelike for NaiveDateTimeimpl<Tz: TimeZone> Timelike for DateTime<Tz>impl Timelike for NaiveTime