FixedOffset

Struct FixedOffset 

pub struct FixedOffset { /* private fields */ }
The time zone with fixed offset, from UTC-23:59:59 to UTC+23:59:59.

Using the TimeZone methods on a FixedOffset struct is the preferred way to construct DateTime<FixedOffset> instances. See the east_opt and west_opt methods for examples.

Implementations

Source

impl FixedOffset

pub fn east(secs: i32) -> FixedOffset

👎Deprecated since 0.4.23:

use east_opt() instead

Makes a new FixedOffset for the Eastern Hemisphere with given timezone difference. The negative secs means the Western Hemisphere.

Panics on the out-of-bound secs.

pub const fn east_opt(secs: i32) -> Option<FixedOffset>

Makes a new FixedOffset for the Eastern Hemisphere with given timezone difference. The negative secs means the Western Hemisphere.

Returns None on the out-of-bound secs.

Example
use chrono::{FixedOffset, TimeZone};
let hour = 3600;
let datetime =
    FixedOffset::east_opt(5 * hour).unwrap().with_ymd_and_hms(2016, 11, 08, 0, 0, 0).unwrap();
assert_eq!(&datetime.to_rfc3339(), "2016-11-08T00:00:00+05:00")
pub fn west(secs: i32) -> FixedOffset

👎Deprecated since 0.4.23:

use west_opt() instead

Makes a new FixedOffset for the Western Hemisphere with given timezone difference. The negative secs means the Eastern Hemisphere.

Panics on the out-of-bound secs.

pub const fn west_opt(secs: i32) -> Option<FixedOffset>

Makes a new FixedOffset for the Western Hemisphere with given timezone difference. The negative secs means the Eastern Hemisphere.

Returns None on the out-of-bound secs.

Example
use chrono::{FixedOffset, TimeZone};
let hour = 3600;
let datetime =
    FixedOffset::west_opt(5 * hour).unwrap().with_ymd_and_hms(2016, 11, 08, 0, 0, 0).unwrap();
assert_eq!(&datetime.to_rfc3339(), "2016-11-08T00:00:00-05:00")
pub const fn local_minus_utc(&self) -> i32

Returns the number of seconds to add to convert from UTC to the local time.

pub const fn utc_minus_local(&self) -> i32

Returns the number of seconds to add to convert from the local time to UTC.