Struct Months

struct Months(_)

A duration in calendar months

Implementations

impl Months

const fn new(num: u32) -> Self

Construct a new Months from a number of months

const fn as_u32(self: &Self) -> u32

Returns the total number of months in the Months instance.

impl Clone for Months

fn clone(self: &Self) -> Months

impl Copy for Months

impl Debug for Months

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Months

impl Freeze for Months

impl Hash for Months

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for Months

fn cmp(self: &Self, other: &Months) -> Ordering

impl PartialEq for Months

fn eq(self: &Self, other: &Months) -> bool

impl PartialOrd for Months

fn partial_cmp(self: &Self, other: &Months) -> Option<Ordering>

impl RefUnwindSafe for Months

impl Send for Months

impl StructuralPartialEq for Months

impl Sync for Months

impl Unpin for Months

impl UnsafeUnpin for Months

impl UnwindSafe for Months

impl<T> Any for Months

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Months

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Months

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Months

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Months

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Months

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Months

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Months

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Months

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>