Struct DelayedFormat

struct DelayedFormat<I> { ... }

A temporary object which can be used as an argument to format! or others. This is normally constructed via format methods of each date and time type.

Implementations

impl<'a, I: Iterator<Item = B> + Clone, B: Borrow<super::Item<'a>>> DelayedFormat<I>

fn new(date: Option<NaiveDate>, time: Option<NaiveTime>, items: I) -> DelayedFormat<I>

Makes a new DelayedFormat value out of local date and time.

fn new_with_offset<Off>(date: Option<NaiveDate>, time: Option<NaiveTime>, offset: &Off, items: I) -> DelayedFormat<I>
where
    Off: Offset + Display

Makes a new DelayedFormat value out of local date and time and UTC offset.

impl<'a, I: Iterator<Item = B> + Clone, B: Borrow<super::Item<'a>>> Display for DelayedFormat<I>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<I> Freeze for DelayedFormat<I>

impl<I> RefUnwindSafe for DelayedFormat<I>

impl<I> Send for DelayedFormat<I>

impl<I> Sync for DelayedFormat<I>

impl<I> Unpin for DelayedFormat<I>

impl<I> UnsafeUnpin for DelayedFormat<I>

impl<I> UnwindSafe for DelayedFormat<I>

impl<I: $crate::fmt::Debug> Debug for DelayedFormat<I>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for DelayedFormat<I>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DelayedFormat<I>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DelayedFormat<I>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for DelayedFormat<I>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToString for DelayedFormat<I>

fn to_string(self: &Self) -> String

impl<T, U> Into for DelayedFormat<I>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DelayedFormat<I>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DelayedFormat<I>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>